@@ -306,6 +306,7 @@ primarySuppression <- function(object, type, ...) {
 #' \item \code{OPT}: protect the complete problem at once using a cut and branch algorithm. The optimal algorithm should be used for small problem-instances only.
 #' \item \code{HITAS}: split the overall problem in smaller problems. These problems are protected using a top-down approach. 
 #' \item \code{HYPERCUBE}: protect the complete problem by protecting sub-tables with a fast heuristic that is based on finding and suppressing geometric structures (n-dimensional cubes) that are required to protect primary sensitive table cells. 
+#' \item \code{SIMPLEPROTECT}: heuristic, quick procedure which might be applied to very large problem instances
 #' }
 #' @param ... parameters used in the protection algorithm that has been selected. Parameters that can be changed are:
 #' \itemize{
@@ -357,13 +358,17 @@ primarySuppression <- function(object, type, ...) {
 #' @export protectTable
 #' @author Bernhard Meindl \email{bernhard.meindl@@statistik.gv.at}
 protectTable <- function(object, method, ...) {
-	if ( !method %in% c('HITAS', 'OPT', 'HYPERCUBE') ) {
-		stop("valid methods are 'HITAS', 'HYPERCUBE' or 'OPT'!\n")
+	if ( !method %in% c('HITAS', 'OPT', 'HYPERCUBE', 'SIMPLEHEURISTIC') ) {
+		stop("valid methods are 'SIMPLEHEURISTIC', 'HITAS', 'HYPERCUBE' or 'OPT'!\n")
 	}
 	
 	paraList <- genParaObj(selection='control.secondary', method=method, ...)
+	if ( method == 'SIMPLEHEURISTIC' ) {
+		out <- performQuickSuppression(object, input=paraList)	
+	} else {
+		out <- calc.sdcProblem(object, type='anonWorker', input=paraList)
+	}
 	
-	out <- calc.sdcProblem(object, type='anonWorker', input=paraList)
 	safeObj <- calc.sdcProblem(out, type='finalize', input=paraList)
 	safeObj
 }
