@@ -318,8 +318,8 @@ genParaObj <- function(selection, ...) {
 		if ( !length(paraObj$approxPerc) & !paraObj$approxPerc %in% 1:100 ) {
 			stop("genPara (type=='control.secondary'): argument 'approxPerc' must be >= 1 and <= 100!\n")
 		}
-		if ( !paraObj$method %in% c('HITAS', 'HYPERCUBE', 'OPT') ) {
-			stop("genPara (type=='control.secondary'): 'method' must be either 'HITAS', 'HYPERCUBE' or 'OPT'!\n")
+		if ( !paraObj$method %in% c('SIMPLEHEURISTIC', 'HITAS', 'HYPERCUBE', 'OPT') ) {
+			stop("genPara (type=='control.secondary'): 'method' must be either 'SIMPLEHEURISTIC', 'HITAS', 'HYPERCUBE' or 'OPT'!\n")
 		}
 		if ( !paraObj$suppMethod %in% c('minSupps', 'minSum', 'minSumLogs') ) {
 			stop("genPara (type=='control.secondary'): 'suppMethod' must be either 'minSupps', 'minSum' or 'minSumLogs'!\n")
@@ -339,3 +339,160 @@ genParaObj <- function(selection, ...) {
 	}		
 	return(paraObj)
 }
+
+
+### Primaersperrungen ###
+# object (class=sdcProblem)
+performQuickSuppression <- function(object, input) {
+	suppMultDimTable <- function(dat, dimVars, freqInd) {
+		# 5dimensionale Tabelle geheimhalten
+		simpleSupp <- function(splList, freqInd) {
+			runInd <- TRUE
+			counter <- 0
+			override <- FALSE
+			while(runInd) {
+				runInd <- FALSE
+				counter <- counter + 1
+				#cat("run:", counter,"\n")
+				for ( i in 1:length(splList)) {
+					allOk <- all(splList[[i]]$sdcStatus %in% c("z"))
+					
+					if ( !allOk & nrow(spl[[i]]) > 1 & length(which(splList[[i]]$sdcStatus %in% c("u", "x")))==1 ) {
+						#cat("we need to doe something: i=",i,"\n")
+						runInd <- TRUE
+						ind.x <- which(splList[[i]]$sdcStatus=='s')
+						f <- splList[[i]][,freqInd]
+						toSupp <- ind.x[order(f[ind.x], decreasing=FALSE)[1]]
+						#cat("toSupp:", toSupp,"\n")
+						if ( is.na(toSupp) ) {
+							#cat("Problem bei i=",i,"\n")
+							ind.x <- which(splList[[i]]$sdcStatus %in% c('s','z') & splList[[i]]$freq!=0)
+							f <- splList[[i]][,freqInd]
+							toSupp <- ind.x[order(f[ind.x], decreasing=FALSE)[1]]	
+							override <- TRUE
+						}
+						splList[[i]]$sdcStatus[toSupp] <- 'x'
+					}
+				}
+			}
+			
+			s <- do.call("rbind", splList)
+			rownames(s) <- NULL
+			suppsAdded <- TRUE
+			if ( counter == 1 ) {
+				suppsAdded <- FALSE
+			}
+			return(list(s=s, suppsAdded=suppsAdded, override=override))
+		}
+		
+		nDims <- length(dimVars)
+		combs <- combn(nDims, nDims-1)
+		
+		runInd <- TRUE
+		counter <- 0
+		override <- FALSE
+		patternOrig <- dat$sdcStatus
+		while ( runInd ) {
+			counter <- counter + 1
+			suppsAdded <- rep(NA, ncol(combs))
+			for ( i in 1:ncol(combs)) {
+				f <- apply(dat, 1, function(x) { paste(x[combs[,i]], collapse="-") } )	
+				spl <- split(dat, f)
+				res <- simpleSupp(spl, freqInd)
+				
+				dat <- res$s
+				if ( override == FALSE & res$override == TRUE) {
+					override <- TRUE
+				}
+				suppsAdded[i] <- res$suppsAdded
+			}
+			#cat("counter:", counter, "\n")
+			#cat("suppsAdded:\n"); print(suppsAdded)
+			if ( all(suppsAdded == FALSE) ) {
+				#cat("finished! (counter=",counter,")\n")
+				runInd <- FALSE	
+			} 
+		}
+		pattern <- dat$sdcStatus
+		pattern[which(dat$sdcStatus =="s")] <- "z"
+		return(list(pattern=pattern, ids=dat$id, override=override))
+	}
+	
+	verbose <- input$verbose
+	pI <- get.sdcProblem(object, type="problemInstance")
+	
+	strIDs <- get.problemInstance(pI, type="strID")
+	
+	dat <- data.frame(
+		id=1:length(strIDs), 
+		strID=strIDs, 
+		freq=get.problemInstance(pI, type="freq"), 
+		sdcStatus=get.problemInstance(pI, type="sdcStatus"), stringsAsFactors=F)
+	
+	indices <- get.sdcProblem(object, type="partition")$indices
+	dimInfo <- get.sdcProblem(object, type="dimInfo")
+	strInfo <- get.dimInfo(dimInfo, type="strInfo")
+	vNames <- get.dimInfo(dimInfo, type="varName")
+	
+	for ( i in seq_along(vNames) ) {
+		dat[,vNames[i]] <- str_sub(dat$strID, strInfo[[i]][1], strInfo[[i]][2])
+	}
+	
+	dimVars <- 1:length(vNames)
+	dat <- cbind(dat[,5:ncol(dat)], dat[,1:4])
+	freqInd <- length(vNames)+2
+	
+	runInd <- TRUE
+	while( runInd ) {
+		override <- FALSE
+		for ( i in 1:length(indices) ) {
+			if ( verbose ) {
+				cat("i=",i,"|",length(indices)," (override=",override,")\n")	
+			}
+			
+			for ( j in 1:length(indices[[i]]) ) {
+				if ( verbose ) {
+					cat("j: ",j,"|",length(indices[[i]]),"\n")
+				}
+				curIndices <- indices[[i]][[j]]
+				subDat <- dat[curIndices,]
+				
+				nrSupps <- length(which(subDat$sdcStatus%in%c("u","x")))
+				
+				if ( nrSupps > 0 ) {
+					if ( verbose ) {
+						cat("length(table): ",length(curIndices),"\n")
+						cat("length(sdcStatus=='u'): ",nrSupps,"\n")
+					}
+					
+					res <- suppMultDimTable(subDat, dimVars, freqInd)
+					matchInd <- match(curIndices, res$ids)
+					dat$sdcStatus[curIndices] <- res$pattern[matchInd]
+					if ( override == FALSE & res$override==TRUE ) {
+						override <- TRUE
+					}
+				} else {
+					ind <- which(subDat$sdcStatus=="s")
+					dat$sdcStatus[curIndices[ind]] <- "z"
+				}
+			}
+		}
+		if ( override == TRUE ) {
+			# alle zellen %in% c("s", "z") muessen auf "s" gesetzt werden
+			dat[dat$sdcStatus %in% c("s","z"),"sdcStatus"] <- "s"
+		} else {
+			if ( verbose ) {
+				cat("finished!\n")	
+			}
+			runInd <- FALSE
+		}
+	}
+	
+	matchID <- match(dat$strID,strIDs )
+	pI <- set.problemInstance(pI, type="sdcStatus", input=list(index=matchID, values=dat$sdcStatus))
+	
+	object <- set.sdcProblem(object, type="problemInstance", list(pI))
+	object	
+}
+
+
